@@ -107,6 +107,10 @@
             4.新增两个信号(colorNamed,clicked)
             5.新增两种风格(Style_Black,Style_White)
     --- 重构 气泡窗口
+2023.1.20 [1.2.17.7]
+    --- 气泡窗口 重构完成,并使用使用了全新的QSS来设置样式
+    --- 轮播组件 重构完成
+    --- 以及更新部分测试用例
 '''
 
 # ===============================================
