@@ -39,6 +39,9 @@ border-radius:30px;
         ''')
         # self.setOpacity(0.7)
 
+        self.setEnableGColor(True)
+        self.setMask(True)
+
         self.flag = False
 
         self.btn = QPushButton("固定",self)
